# encoding: utf-8
from south.db import db
from south.v2 import SchemaMigration
from django.db import models
from longerusername import MAX_USERNAME_LENGTH

class Migration(SchemaMigration):

    def forwards(self, orm):
        # Changing field 'User.username'
        db.alter_column('auth_user', 'username', models.CharField(max_length=MAX_USERNAME_LENGTH()))
        # Increase length of email field to match
        db.alter_column('auth_user', 'email', models.CharField(max_length=MAX_USERNAME_LENGTH()))
        # Add an index to make email field unique
        db.create_index('auth_user', ['email'], unique=True)


    def backwards(self, orm):

        # Changing field 'User.username'
        db.alter_column('auth_user', 'username', models.CharField(max_length=35))
        db.alter_column('auth_user', 'email', models.CharField(max_length=75))
        db.create_index('auth_user', ['email'], unique=False)

    models = {
        
    }

    complete_apps = ['django_monkeypatches']



from django.contrib.auth.models import User
from django.test import TestCase


class LongerUsernameAndEmailTests(TestCase):
    """
    Unit tests for longerusernameandemail app
    """
    def setUp(self):
        """
        creates a user with a terribly long username
        """
        long_username = ''.join([str(i) for i in range(100)])

        self.user = User.objects.create_user(
            'test%s' % long_username,
            '%s@example.com' % long_username,
            'testpassword'
        )

    def testUserCreation(self):
        """
        tests that self.user was successfully saved, and can be retrieved
        """
        self.assertNotEqual(self.user, None)

        # returns DoesNotExist error if the user wasn't created
        User.objects.get(id=self.user.id)



from django.utils.translation import ugettext as _
from django.core.validators import MaxLengthValidator
from django.contrib.auth import forms as auth_forms


from longerusernameandemail import MAX_USERNAME_LENGTH


def update_field_length(field):
    field.widget.attrs['maxlength'] = MAX_USERNAME_LENGTH()
    field.max_length = MAX_USERNAME_LENGTH()
    field.help_text = _("Required, %s characters or fewer. Only letters, "
                        "numbers, and characters such as @.+_- are "
                        "allowed." % MAX_USERNAME_LENGTH())

    # we need to find the MaxLengthValidator and change its
    # limit_value otherwise the auth forms will fail validation
    for v in field.validators:
        if isinstance(v, MaxLengthValidator):
            v.limit_value = MAX_USERNAME_LENGTH()


class UserCreationForm(auth_forms.UserCreationForm):
    def __init__(self, *args, **kwargs):
        super(UserCreationForm, self).__init__(*args, **kwargs)
        update_field_length(self.fields['username'])
        update_field_length(self.fields['email'])


class UserChangeForm(auth_forms.UserChangeForm):
    def __init__(self, *args, **kwargs):
        super(UserChangeForm, self).__init__(*args, **kwargs)
        update_field_length(self.fields['username'])
        update_field_length(self.fields['email'])


class AuthenticationForm(auth_forms.AuthenticationForm):
    def __init__(self, *args, **kwargs):
        super(AuthenticationForm, self).__init__(*args, **kwargs)
        update_field_length(self.fields['username'])
        update_field_length(self.fields['email'])



from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from django.contrib.auth.models import User

from longerusernameandemail.forms import UserCreationForm, UserChangeForm


class LongerUsernameAndEmailUserAdmin(UserAdmin):
    add_form = UserCreationForm
    form = UserChangeForm


admin.site.unregister(User)
admin.site.register(User, LongerUsernameAndEmailUserAdmin)
